# Changes to roboherd

## 0.1.4 ([Milestone](https://codeberg.org/bovine/roboherd/milestone/10442))

- Type check the project
- No longer require bovine [roboherd#26](https://codeberg.org/bovine/roboherd/issues/26)
- Fixed typo in Dockerfile [roboherd#28](https://codeberg.org/bovine/roboherd/issues/28)

## 0.1.3 ([Milestone](https://codeberg.org/bovine/roboherd/milestone/10441))

- Add information about developement [roboherd#24](https://codeberg.org/bovine/roboherd/issues/24)
- Repair docker build [roboherd#23](https://codeberg.org/bovine/roboherd/issues/23)

## 0.1.1 ([Milestone](https://codeberg.org/bovine/roboherd/milestone/10245))

- Document environment variable overrides [roboherd#16](https://codeberg.org/bovine/roboherd/issues/16)
- Add minimal password length (6 characters) for roboherd register
- Finish documentation [roboherd#6](https://codeberg.org/bovine/roboherd/issues/6)
- Add a roboherd register command
- Repair bovine annotations [roboherd#11](https://codeberg.org/bovine/roboherd/issues/11)
- Enable setting the type of the actor [roboherd#9](https://codeberg.org/bovine/roboherd/issues/9)
- Enable setting PropertyValues for the cow actor [roboherd#4](https://codeberg.org/bovine/roboherd/issues/4)
